@@ -99,7 +99,7 @@ class ArrayType(AnyType[KiaraArray, DataTypeConfig]):
         serialized = SerializationResult(**serialized_data)
         return serialized
 
-    def render_as__terminal_renderable(
+    def pretty_print_as__terminal_renderable(
         self, value: Value, render_config: Mapping[str, Any]
     ) -> Any:
 
@@ -224,7 +224,7 @@ class TableType(AnyType[KiaraTable, DataTypeConfig]):
         serialized = SerializationResult(**serialized_data)
         return serialized
 
-    def render_as__terminal_renderable(
+    def pretty_print_as__terminal_renderable(
         self, value: "Value", render_config: Mapping[str, Any]
     ) -> Any:
 
