@@ -1,16 +1,20 @@
 # -*- coding: utf-8 -*-
-from typing import TYPE_CHECKING, Any, Iterable, Optional
+from typing import Any, Iterable, List, Optional
 
 import pyarrow as pa
 from kiara.models import KiaraModel
+from kiara.models.render_value import (
+    RenderInstruction,
+    RenderMetadata,
+    RenderValueResult,
+)
+from kiara.models.values.value import Value
 from kiara.models.values.value_metadata import ValueMetadata
+from kiara.utils.output import ArrowTabularWrap
 from pydantic import Field, PrivateAttr
 
 from kiara_plugin.tabular.models import TableMetadata
 
-if TYPE_CHECKING:
-    from kiara.models.values.value import Value
-
 
 class KiaraArray(KiaraModel):
 
@@ -55,6 +59,8 @@ class KiaraArray(KiaraModel):
             )
 
         obj = KiaraArray()
+        if not isinstance(array_obj, pa.lib.ChunkedArray):
+            array_obj = pa.chunked_array(array_obj)
         obj._array_obj = array_obj
         return obj
 
@@ -112,7 +118,7 @@ class KiaraTable(KiaraModel):
 
         if table_obj is None:
             raise Exception(
-                f"Can't create array, invalid source data type: {type(data)}."
+                f"Can't create table, invalid source data type: {type(data)}."
             )
 
         obj = KiaraTable()
@@ -202,3 +208,66 @@ class KiaraTableMetadata(ValueMetadata):
         return KiaraTableMetadata.construct(table=md)
 
     table: TableMetadata = Field(description="The table schema.")
+
+
+class RenderTableInstruction(RenderInstruction):
+    @classmethod
+    def retrieve_source_type(cls) -> str:
+        return "table"
+
+    _kiara_model_id = "instance.render_instruction.table"
+    number_of_rows: int = Field(description="How many rows to display.", default=20)
+    row_offset: int = Field(description="From which row to start.", default=0)
+    columns: Optional[List[str]] = Field(
+        description="Which rows do display.", default=None
+    )
+
+    def render_as__terminal_renderable(self, value: Value):
+
+        import duckdb
+
+        table: KiaraTable = value.data
+
+        columnns: Iterable[str] = self.columns  # type: ignore
+        if not columnns:
+            columnns = table.column_names
+
+        assert columnns
+
+        query = f"""SELECT {', '.join(columnns)} FROM data ORDER by {', '.join(columnns)} LIMIT {self.number_of_rows} OFFSET {self.row_offset}"""
+
+        rel_from_arrow = duckdb.arrow(table.arrow_table)
+        query_result: duckdb.DuckDBPyResult = rel_from_arrow.query("data", query)
+
+        result_table = query_result.fetch_arrow_table()
+
+        wrap = ArrowTabularWrap(table=result_table)
+        pretty = wrap.pretty_print()
+
+        related_instructions = {}
+
+        related_instructions["first"] = RenderTableInstruction.construct(
+            **{"row_offset": 0, "columns": self.columns}
+        )
+
+        if self.row_offset > 0:
+            p_offset = self.row_offset - self.number_of_rows
+            if p_offset < 0:
+                p_offset = 0
+            previous = {"row_offset": p_offset, "columns": self.columns}
+            related_instructions["previous"] = RenderTableInstruction.construct(
+                **previous
+            )
+
+        n_offset = self.row_offset + self.number_of_rows
+        if n_offset < table.num_rows:
+            next = {"row_offset": n_offset, "columns": self.columns}
+            related_instructions["next"] = RenderTableInstruction.construct(**next)
+
+        related_instructions["last"] = RenderTableInstruction.construct(
+            **{"row_offset": table.num_rows - self.number_of_rows, "columns": columnns}
+        )
+
+        render_metadata = RenderMetadata(related_instructions=related_instructions)
+
+        return RenderValueResult(rendered=pretty, metadata=render_metadata)
